.. _sec_coderef:

==============
Code reference
==============

.. toctree::
  :maxdepth: 2


.. autoclass:: bmlab.file.BrillouinFile
   :members:

.. autoclass:: bmlab.file.Repetition
   :members:

.. autoclass:: bmlab.file.Payload
   :members:

.. autoclass:: bmlab.file.Calibration
   :members:

.. automodule:: bmlab.file
   :members:
